Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6082)

Unified Diff: chrome/browser/extensions/extension_function.h

Issue 10694106: Added support for multiple parameters to Extension API callbacks. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Synced. Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_function.h
diff --git a/chrome/browser/extensions/extension_function.h b/chrome/browser/extensions/extension_function.h
index e0c2a9bae3e4a07c79dea94e0a5fb990e4f93f09..af2074e1c797bea69ac32b0bfa414a4e85145704 100644
--- a/chrome/browser/extensions/extension_function.h
+++ b/chrome/browser/extensions/extension_function.h
@@ -107,8 +107,11 @@ class ExtensionFunction
// Specifies the raw arguments to the function, as a JSON value.
virtual void SetArgs(const base::ListValue* args);
- // Retrieves the results of the function as a Value.
- const base::Value* GetResultValue();
+ // Sets a single Value as the results of the function.
+ void SetResult(base::Value* result);
+
+ // Retrieves the results of the function as a ListValue.
+ const base::ListValue* GetResultList();
// Retrieves any error string from the function.
virtual const std::string GetError();
@@ -206,9 +209,9 @@ class ExtensionFunction
// The arguments to the API. Only non-null if argument were specified.
scoped_ptr<base::ListValue> args_;
- // The result of the API. This should be populated by the derived class before
- // SendResponse() is called.
- scoped_ptr<base::Value> result_;
+ // The results of the API. This should be populated by the derived class
+ // before SendResponse() is called.
+ scoped_ptr<base::ListValue> results_;
// Any detailed error from the API. This should be populated by the derived
// class before Run() returns.

Powered by Google App Engine
This is Rietveld 408576698